<?php

namespace App\Service;

use App\Exception;

use SimpleXMLElement;

class IntegrationService {
    
    private $util;
    private $integrationFactory;

    public function __construct (\App\Util\Util $util,
                                 \App\Factory\IntegrationFactory $integrationFactory) {

        $this->util                 = $util;
        $this->integrationFactory   = $integrationFactory;
    }
    
    public function buildXml($response, $message, $success, $isNewOrder = false) {
        $xml = new \SimpleXMLElement('<root/>');
    
        $xml->addChild('success', ($success ? 'true' : 'false'), '');
        $xml->addChild('message', $message, '');
        
        if($success && $isNewOrder){
            $xml->addChild('RoteirizadorId', $response['Id'], '');
        }
        
        $xmlString = preg_replace('/ xmlns=""\s?/', '', $xml->asXML());
        
        return $xmlString;
    }
    
    public function buildOrderXml($response, $message, $success){
        $xml = new \SimpleXMLElement('<root/>');
        
        $xml->addChild('success', ($success ? 'true' : 'false'), '');
        
        if($success){
            $orderData = $xml->addChild('orderData', "", '');
            
            $orderData->addChild('Id', $response['Id'], '');
            $orderData->addChild('Name', $response['Name'], '');
            $orderData->addChild('telefone', $response['telefone'], '');
            $orderData->addChild('Rua', $response['Rua'], '');
            $orderData->addChild('Numero', $response['Numero'], '');
            $orderData->addChild('Bairro', $response['Bairro'], '');
            $orderData->addChild('Origem', $response['Origem'], '');
            $orderData->addChild('DataHoraPedido', $response['DataHoraPedido'], '');
            $orderData->addChild('DataHoraPronto', $response['DataHoraPronto'], '');
            $orderData->addChild('Valor', $response['Valor'], '');
            $orderData->addChild('status', $response['status'], '');
            $orderData->addChild('numeroVenda', $response['numeroVenda'], '');
            
            $xmlEntregador = $orderData->addChild('entregador', "", '');
            $xmlData = $xmlEntregador->addChild('data', "", '');
            
            $xmlData->addChild('Id', $response['entregador']['data']['Id'], '');
            $xmlData->addChild('Name', $response['entregador']['data']['Name'], '');
            $xmlData->addChild('cpf', $response['entregador']['data']['cpf'], '');
            
            $xmlRota = $orderData->addChild('Rota', "", '');
            $xmlData = $xmlRota->addChild('data', "", '');
            
            $xmlData->addChild('Id', $response['Rota']['data']['Id'], '');
            $xmlData->addChild('DataHoraInicio', $response['Rota']['data']['DataHoraInicio'], '');
            $xmlData->addChild('Usuario', $response['Rota']['data']['Usuario'], '');
            
            $xmlEmpresa = $orderData->addChild('empresa', "", '');
            $xmlData = $xmlEmpresa->addChild('data', "", '');
            
            $xmlData->addChild('Id', $response['empresa']['data']['Id'], '');
            $xmlData->addChild('Name', $response['empresa']['data']['Name'], '');
            $xmlData->addChild('Mall_id', $response['empresa']['data']['Mall_id'], '');
            
            $xmlItens = $orderData->addChild('ItensPedido', "", '');
            foreach($response['ItensPedido'] as $itensData){
                $xmlData = $xmlItens->addChild('data', "", '');
                
                $xmlData->addChild('Id', $itensData['Id'], '');
                $xmlData->addChild('codigo', $itensData['codigo'], '');
                $xmlData->addChild('Descricao', $itensData['Descricao'], '');
                $xmlData->addChild('ValorUnit', $itensData['ValorUnit'], '');
                $xmlData->addChild('Quantidade', $itensData['Quantidade'], '');
                $xmlData->addChild('ValorTotal', $itensData['ValorTotal'], '');
                $xmlData->addChild('Observacao', $itensData['Observacao'], '');
            }
            
            $xmlPagamentos = $orderData->addChild('Pagamentos', "", '');
            foreach($response['Pagamentos'] as $pagamentosData){
                $xmlData = $xmlPagamentos->addChild('data', "", '');
                
                $xmlData->addChild('Id', $pagamentosData['Id'], '');
                $xmlData->addChild('Sequencia', $pagamentosData['Sequencia'], '');
                $xmlData->addChild('codigo', $pagamentosData['codigo'], '');
                $xmlData->addChild('Descricao', $pagamentosData['Descricao'], '');
                $xmlData->addChild('Valor', $pagamentosData['Valor'], '');
                $xmlData->addChild('troco', $pagamentosData['troco'], '');
            }
        } else{
            $xml->addChild('message', $message, '');
        }
        
        $xmlString = preg_replace('/ xmlns=""\s?/', '', $xml->asXML());
        
        return $xmlString;
    }

}
